Run the analytic_locFDR_BF_cor function to analytically compute the local FDR & Bayes factor (BF)
that quantifies the evidence of aggregate-level pleiotropic association for correlated summary statistics.
Here a fixed value of slab variance is considred instead of a range of it in cpbayes_cor.
analytic_locFDR_BF_cor(BetaHat, SE, Corln, SpikeVar = 1e-04, SlabVar = 0.8)A numeric vector of length K where K is the number of phenotypes. It contains the beta-hat values across studies/traits. No default.
A numeric vector with the same dimension as BetaHat providing the standard errors corresponding to BetaHat. Every element of SE must be positive. No default.
A numeric square matrix of order K by K providing the correlation matrix of BetaHat.
The number of rows & columns of Corln must be the same as the length of BetaHat. No default
is specified. See estimate_corln.
Variance of spike (normal distribution with small variance) representing the null effect distribution. Default is 10^(-4).
Variance of slab normal distribution representing the non-null effect distribution. Default is 0.8.
The output produced by the function is a list which consists of the local FDR and log10(Bayes factor).
It provides the analytically computed local false discovery rate (posterior probability of null association) under CPBayes model (a Bayesian analog of the p-value) which is a measure of the evidence of the aggregate-level pleiotropic association. Bayes factor is adjusted for prior odds, but locFDR is solely a function of the posterior odds.
It provides the analytically computed log10(Bayes factor) produced by CPBayes that measures the evidence of the overall pleiotropic association.
Majumdar A, Haldar T, Bhattacharya S, Witte JS (2018) An efficient Bayesian meta analysis approach for studying cross-phenotype genetic associations. PLoS Genet 14(2): e1007139.
cpbayes_cor, estimate_corln, analytic_locFDR_BF_uncor, cpbayes_uncor, post_summaries, forest_cpbayes
# NOT RUN {
data(ExampleDataCor)
BetaHat <- ExampleDataCor$BetaHat
BetaHat
SE <- ExampleDataCor$SE
SE
cor <- ExampleDataCor$cor
cor
result <- cpbayes_cor(BetaHat, SE, cor)
str(result)
# }
Run the code above in your browser using DataLab