The output produced by this function is a diagram file in .pdf format. The details of the diagram are as follows:
file_nameThe pdf file is named after the genetic variant. So, if the argument `Variant'
in cpbayes_uncor or cpbayes_cor is specified as 'rs1234', the figure file is named as rs1234.pdf.
Column1First column in the figure specifies the name of the phenotypes.
Column2Second column provides the trait-specific univariate association p-value for a trait.
Column3Third column provides the trait-specific posterior probability of association (PPAj) produced by CPBayes.
Column4Fourth column states whether a phenotype was selected in the optimal subset of associated/non-null traits
detected by CPBayes. If a phenotype was not selected, selected and positively associated, selected and negatively associated,
its association status is stated as null, positive and negative, respectively.
Column5In the right section of the figure, the primary eatimate and confidence interval of the beta/log odds ratio parameter for
a trait is plotted.